IKdfHostConfig class sealed
Define IKdfHostConfig as an abstract interface class
- Implementers
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- https → bool
-
final
- rpcPassword → String
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
getConnectionParams(
) → Map< String, dynamic> -
Each host config must implement the
getConnectionParamsmethod. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited