KdfStartupResult enum

Inheritance
Available extensions

Values

ok → const KdfStartupResult

Operation completed successfully

invalidParams → const KdfStartupResult

Invalid parameters were provided to the function

configError → const KdfStartupResult

The configuration was invalid (missing required fields, etc.)

alreadyRunning → const KdfStartupResult

MM2 is already running

initError → const KdfStartupResult

MM2 initialization failed

spawnError → const KdfStartupResult

Failed to spawn the MM2 process/thread

unknownError → const KdfStartupResult

Unknown result code

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isAlreadyRunning bool
no setter
isOk bool
no setter
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

isStartingOrAlreadyRunning() bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<KdfStartupResult>
A constant List of the values in this enum, in order of their declaration.