dispose method
Closes the log stream and cancels the logger subscription.
NB! This does not stop the KDF operations or the KDF process.
Implementation
Future<void> dispose() async {
await _logStream.close();
await _loggerSub?.cancel();
}
Closes the log stream and cancels the logger subscription.
NB! This does not stop the KDF operations or the KDF process.
Future<void> dispose() async {
await _logStream.close();
await _loggerSub?.cancel();
}