LocalConfig class

LocalConfig class now implements IKdfHostConfig interface

Inheritance

Constructors

LocalConfig({required bool https, required String rpcPassword})
LocalConfig.fromJson(JsonMap json)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
https bool
finalinherited
rpcPassword String
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

getConnectionParams() Map<String, dynamic>
Each host config must implement the getConnectionParams method.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited