AwsConfig class
AwsConfig class now implements IKdfHostConfig interface
- Inheritance
-
- Object
- IKdfHostConfig
- AwsConfig
Constructors
Properties
- accessKey → String
-
final
- amiId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- https → bool
-
finalinherited
- instanceId → String?
-
final
- instanceType → String
-
final
- keyName → String?
-
final
- region → String
-
final
- rpcPassword → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secretKey → String
-
final
- securityGroup → String?
-
final
Methods
-
getConnectionParams(
) → Map< String, dynamic> -
Each host config must implement the
getConnectionParamsmethod.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited