DigitalOceanConfig class
DigitalOceanConfig class now implements IKdfHostConfig interface
- Inheritance
-
- Object
- IKdfHostConfig
- DigitalOceanConfig
Constructors
- DigitalOceanConfig({required String apiToken, required String rpcPassword, required bool https, String? dropletId, String dropletRegion = 'nyc1', String dropletSize = 's-1vcpu-1gb', String? sshKeyId, String image = 'ubuntu-20-04-x64'})
- DigitalOceanConfig.fromJson(JsonMap json)
-
factory
Properties
- apiToken → String
-
final
- dropletId → String?
-
final
- dropletRegion → String
-
final
- dropletSize → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- https → bool
-
finalinherited
- image → String
-
final
- rpcPassword → String
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sshKeyId → String?
-
final
Methods
-
getConnectionParams(
) → Map< String, dynamic> -
Each host config must implement the
getConnectionParamsmethod.override -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited