Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- operationsName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isAvailable(
IKdfHostConfig hostConfig) → Future< bool> - Determines if the KDF is available without considering its current state.
-
isRunning(
) → Future< bool> -
kdfMain(
JsonMap startParams, {int? logLevel}) → Future< KdfStartupResult> -
kdfMainStatus(
) → Future< MainStatus> -
kdfStop(
) → Future< StopStatus> -
mm2Rpc(
Map< String, dynamic> request) → Future<Map< String, dynamic> > -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
validateSetup(
) → Future< void> -
version(
) → Future< String?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited