KdfStartupConfig class
Properties
- allowRegistrations → bool
-
final
- allowWeakPassword → bool
-
final
- coins → dynamic
-
final
- dbDir → String?
-
final
- disableP2p → bool?
-
final
- enableHd → bool?
-
final
- gui → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- hdAccountId → int?
-
final
- https → bool
-
final
- iAmSeed → bool?
-
final
- isBootstrapNode → bool?
-
final
- netid → int
-
final
- rpcIp → String?
-
final
- rpcLocalOnly → bool?
-
final
- rpcPassword → String
-
final
- rpcPort → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- seed → String?
-
final
-
seedNodes
→ List<
String> ? -
final
- userHome → String?
-
final
- walletName → String?
-
final
- walletPassword → String?
-
final
Methods
-
encodeStartParams(
) → JsonMap -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
generateWithDefaults(
{required String walletName, required String walletPassword, required bool? enableHd, String? rpcPassword, String? coinsPath, String? seed, String? dbDir, String? userHome, String? rpcIp, int? hdAccountId, bool allowWeakPassword = false, int rpcPort = 7783, int netid = kDefaultNetId, String gui = 'komodo-defi-flutter-auth', bool https = false, bool rpcLocalOnly = true, bool allowRegistrations = true, List< String> ? seedNodes, bool? disableP2p, bool? iAmSeed, bool? isBootstrapNode}) → Future<KdfStartupConfig> -
noAuthStartup(
{String? rpcPassword, String? rpcIp, int rpcPort = 7783}) → Future< KdfStartupConfig>