KomodoDefiFramework class
Constructors
- KomodoDefiFramework.create({required IKdfHostConfig hostConfig, void externalLogger(String)?})
-
factory
- KomodoDefiFramework.createWithOperations({required IKdfHostConfig hostConfig, required IKdfOperations kdfOperations, void externalLogger(String)?})
-
TODO: Test if this factory method works as expected.
factory
Properties
- client → ApiClient
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
logStream
→ Stream<
String> -
no setter
- operationsName → String
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → Future< void> - Closes the log stream and cancels the logger subscription.
-
executeRpc(
JsonMap request) → Future< JsonMap> -
isRunning(
) → Future< bool> -
kdfMainStatus(
) → Future< MainStatus> -
kdfStop(
) → Future< StopStatus> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
startKdf(
KdfStartupConfig startupConfig, {bool validateHostConfig = true}) → Future< KdfStartupResult> -
toString(
) → String -
A string representation of this object.
inherited
-
version(
) → Future< String?>
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited