SeedNodeService class
Service class responsible for fetching and managing seed nodes.
This class follows the Single Responsibility Principle by focusing solely on seed node acquisition and management.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fetchSeedNodes(
{bool filterForWeb = kIsWeb}) → Future< ({int netId, List< String> seedNodes})> - Fetches seed nodes from the remote configuration with fallback to defaults.
-
getDefaultSeedNodes(
) → List< String> - Gets the default seed nodes if remote fetching fails.
-
getSeedNodes(
{List< String> ? seedNodes, bool? disableP2p, bool fetchRemote = true}) → Future<List< String> ?> - Gets seed nodes based on configuration preferences.