getDefaultSeedNodes static method
Gets the default seed nodes if remote fetching fails.
Note: From v2.5.0-beta, there will be no default seed nodes, and the seednodes parameter will be required unless disable_p2p is set to true.
Implementation
static List<String> getDefaultSeedNodes() {
return SeedNodeValidator.getDefaultSeedNodes();
}